CircuitState enum

Represents the operating states of a CircuitBreaker.

Inheritance
Available extensions

Values

closed → const CircuitState

Normal operation. Requests flow through freely and failures are tracked.

open → const CircuitState

Service is considered unhealthy. Requests fast-fail immediately with CircuitOpenException until CircuitBreakerConfig.resetTimeout expires.

halfOpen → const CircuitState

Probe mode. A limited number of trial requests are allowed through to verify whether the downstream service has recovered.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CircuitState>
A constant List of the values in this enum, in order of their declaration.