ConnectivityPlusDetector class

Layer 1 detector implementation using the official connectivity_plus plugin.

Implemented types

Constructors

ConnectivityPlusDetector([Connectivity? connectivity])

Properties

hashCode int
The hash code for this object.
no setterinherited
onInterfaceChange Stream<List<NetworkInterfaceType>>
A stream that emits whenever the device's network interfaces change.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkInterfaces() Future<List<NetworkInterfaceType>>
Checks the currently active network interfaces right now.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited