PackageHttpResponseExtractor class

An HttpResponseExtractor specialized for extracting HTTP metadata from HttpRetryResponseException or http.ClientException.

Implemented types

Constructors

PackageHttpResponseExtractor()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extract(Object error) HttpResponseSnapshot?
Extracts status code, method, and Retry-After header from error.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited